==> keycloak-model-map-hot-rod-20.0.2-sources.jar: org/keycloak/models/map/storage/hotRod/authorization/HotRodResourceServerEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.authorization;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
public class HotRodResourceServerEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceServerEntity, org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceServerEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.authorization.model.ResourceServer.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceServerEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceServerEntity.class;
    }
    @Override
    public String getCacheName() {
        return "authz";
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceServerEntity, org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceServerEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceServerEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceServerEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceServerEntity.HotRodResourceServerEntitySchema.INSTANCE;
    }
}

==> keycloak-model-map-hot-rod-22.0.5-sources.jar: org/keycloak/models/map/storage/hotRod/authorization/HotRodResourceServerEntityDescriptor.java <==
package org.keycloak.models.map.storage.hotRod.authorization;
import org.infinispan.protostream.GeneratedSchema;
import java.util.function.Function;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateHotRodEntityImplementationsProcessor")
public class HotRodResourceServerEntityDescriptor implements org.keycloak.models.map.storage.hotRod.common.HotRodEntityDescriptor<org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceServerEntity, org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceServerEntityDelegate> {
    @Override
    public Class<?> getModelTypeClass() {
        return org.keycloak.authorization.model.ResourceServer.class;
    }
    @Override
    public Class<org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceServerEntity> getEntityTypeClass() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceServerEntity.class;
    }
    @Override
    public String getCacheName() {
        return "authz";
    }
    @Override
    public Function<org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceServerEntity, org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceServerEntityDelegate> getHotRodDelegateProvider() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceServerEntityDelegate::new;
    }
    @Override
    public Integer getCurrentVersion() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceServerEntity.VERSION;
    }
    @Override
    public GeneratedSchema getProtoSchema() {
        return org.keycloak.models.map.storage.hotRod.authorization.HotRodResourceServerEntity.HotRodResourceServerEntitySchema.INSTANCE;
    }
}
